<?php
/**
 * STMPack functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package STMPack
 */




if ( ! function_exists( 'stm_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function stm_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on STMPack, use a find and replace
	 * to change 'stm' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'stm', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	// add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );


	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary', 'stm' ),
		'secondary' => esc_html__( 'Secondary', 'stm' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'stm_custom_background_args', array(
		'default-color' => 'ffffff'
	) ) );

	add_post_type_support( 'page', 'excerpt' );

	//remove_filter('template_redirect', 'redirect_canonical');
}
endif;
add_action( 'after_setup_theme', 'stm_setup' );


/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function stm_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Right Sidebar', 'stm' ),
		'id'            => 'stm-right-sidebar',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Left Sidebar', 'stm' ),
		'id'            => 'stm-left-sidebar',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer 1', 'stm' ),
		'id'            => 'stm-footer1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer 2', 'stm' ),
		'id'            => 'stm-footer2',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer 3', 'stm' ),
		'id'            => 'stm-footer3',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer 4', 'stm' ),
		'id'            => 'stm-footer4',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer 5', 'stm' ),
		'id'            => 'stm-footer5',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="clearfix widget-full widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
	
		register_sidebar( array(
		'name'          => esc_html__( 'Blog', 'stm' ),
		'id'            => 'stm-blog',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="clearfix widget-full widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
	 
}
add_action( 'widgets_init', 'stm_widgets_init' );

function get_youtube_videos($lang) {

	$apiUrl = 'https://www.googleapis.com/youtube/v3/';
	$apiKey = 'AIzaSyA__YjlmHDojfe0CazB86bQswdpvJ3FDIk';
	$apiKeyParam = '&key=' . $apiKey;
	$playlistId = '8M8eIl4hfyMoIlh9M5TkKaBhgU0YkAKh';
	$playlistParam = 'playlistItems?part=snippet&order=date&maxResults=50&playlistId=' . $playlistId;
	$videosParam = 'videos?part=snippet&q&id=';
	$langParam = '&hl=' . $lang;

	$videosUrl = $apiUrl . $videosParam;
	$playlistUrl = $apiUrl . $playlistParam . $apiKeyParam;
    
    $playlistResponse = wp_remote_get( $playlistUrl,  array( 'timeout' => 15 ) );


    if( ! is_wp_error( $playlistResponse ) 
        && isset( $playlistResponse['response']['code'] )        
        && 200 === $playlistResponse['response']['code'] )
    {
        $body = wp_remote_retrieve_body( $playlistResponse );
        $bodyJSON = json_decode($body);
        $items = $bodyJSON->items;
        $itemsQ = '';

        foreach ($items as $item) {
        	$itemsQ = $itemsQ . $item->snippet->resourceId->videoId . ',';
        }

        $itemsQ = rtrim($itemsQ, ',');
        $videosUrl = $videosUrl . $itemsQ . $langParam . $apiKeyParam;

        $videosResponse = wp_remote_get( $videosUrl,  array( 'timeout' => 15 ) );

        if( ! is_wp_error( $videosResponse ) && isset( $videosResponse['response']['code'] ) && 200 === $videosResponse['response']['code'] ) {

        	$videos = wp_remote_retrieve_body( $videosResponse );

        	return $videos;

        }

    }
    return null;
}

/**
 * Enqueue scripts and styles.
 */
function stm_scripts() {

	$deployVer = '20190122152';

	wp_enqueue_style( 'stm-style-base', get_template_directory_uri() . '/css/base.css', array(), $deployVer );
	wp_enqueue_style( 'stm-style', get_stylesheet_uri(), array(), $deployVer );

	wp_enqueue_script( 'stm-scripts-libs', get_template_directory_uri() . '/js/stm-scripts-libs.min.js', array(), $deployVer, true );

	wp_enqueue_script( 'stm-scripts', get_template_directory_uri() . '/js/stm-scripts.js', array(), $deployVer, true );
}
add_action( 'wp_enqueue_scripts', 'stm_scripts' );

/**
 * Enqueue admin style
 */
function stm_admin_scripts() {
	wp_enqueue_style( 'stm-admin-style', get_template_directory_uri() . '/inc/css/admin-style.css', array(), '1.0' );
}
add_action( 'admin_enqueue_scripts', 'stm_admin_scripts' );

/**
 * Set language for reCaptcha in Contact Form 7
 */
// remove_action( 'wpcf7_enqueue_scripts', 'wpcf7_recaptcha_enqueue_scripts' );
// add_action( 'wpcf7_enqueue_scripts', 'mytheme_wpcf7_recaptcha_enqueue_scripts' );

// function mytheme_wpcf7_recaptcha_enqueue_scripts() {
//     $hl = get_locale();

//     $url = 'https://www.google.com/recaptcha/api.js';
//     $url = add_query_arg( array(
//         'hl' => $hl,
//         'onload' => 'recaptchaCallback',
//         'render' => 'explicit' ), $url );

//     wp_register_script( 'google-recaptcha', $url, array(), '2.0', true );
// }

/**
 * Disable wp emoji
 */

function disable_emojicons_tinymce( $plugins ) {
  if ( is_array( $plugins ) ) {
    return array_diff( $plugins, array( 'wpemoji' ) );
  } else {
    return array();
  }
}

function disable_wp_emojicons() {

  // all actions related to emojis
  remove_action( 'admin_print_styles', 'print_emoji_styles' );
  remove_action( 'wp_head', 'print_emoji_detection_script', 7 );
  remove_action( 'admin_print_scripts', 'print_emoji_detection_script' );
  remove_action( 'wp_print_styles', 'print_emoji_styles' );
  remove_filter( 'wp_mail', 'wp_staticize_emoji_for_email' );
  remove_filter( 'the_content_feed', 'wp_staticize_emoji' );
  remove_filter( 'comment_text_rss', 'wp_staticize_emoji' );

  // filter to remove TinyMCE emojis
  add_filter( 'tiny_mce_plugins', 'disable_emojicons_tinymce' );
}
add_action( 'init', 'disable_wp_emojicons' );
add_filter( 'emoji_svg_url', '__return_false' );


/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom page metabox
 */
require get_template_directory() . '/inc/metabox.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Add text blocks.
 */
require get_template_directory() . '/inc/text-blocks/text-blocks.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
 * Custom breadcrumbs
 */
require get_template_directory() . '/inc/custom-breadcrumbs.php';


/**
 * Remove word 'category' from category title
 */
function remove_category_word_from_archive_title( $title ) {
    $title = str_replace( 'Category:', '', $title );
    return $title;
}

add_filter( 'get_the_archive_title', 'remove_category_word_from_archive_title' );

function fake_wpml_object_id( $page ) {
    return $page->ID;
}
add_filter( 'wpml_object_id', 'fake_wpml_object_id' );

/**
 * Disable admin bar
 */
add_filter('show_admin_bar', '__return_false');

/**
 * Filter language switcher links
 */
 
function modify_language_link( $url, $slug ) {
	$rurl = str_replace('https://34.196.57.174', '', $url);
	$rurl = str_replace('https://stm-pack.com', '', $rurl);
	$rurl = str_replace('http://localhost:13080', '', $rurl);

	$lang = ('en' == $slug) ? '' : '/' . $slug;
	$new_url = 'https://stm-pack.com' . $lang . $rurl;

	$new_url = str_replace('pl/pl', 'pl', $new_url);
	$new_url = str_replace('ru/ru', 'ru', $new_url);
	$new_url = str_replace('fr/fr', 'fr', $new_url);
	$new_url = str_replace('fa/fa', 'fa', $new_url);
	$new_url = str_replace('es/es', 'es', $new_url);
    return $new_url;
}
add_filter( 'pll_the_language_link', 'modify_language_link', 10, 2 );

/**
 * Remove recent comment css
 */
function remove_recent_comments_style() {
    global $wp_widget_factory;
    remove_action('wp_head', array($wp_widget_factory->widgets['WP_Widget_Recent_Comments'], 'recent_comments_style'));
}
add_action('widgets_init', 'remove_recent_comments_style');

/**
 * Filter canonical link
 */

// define the wpseo_canonical callback 
function filter_wpseo_canonical( $canonical ) { 
    $replin = array("http:", "34.196.57.174");
	$replout = array("https:", "stm-pack.com");
	$r_canonical = str_replace($replin, $replout, $canonical);
    return $r_canonical; 
}; 
         
// add the filter 
add_filter( 'wpseo_canonical', 'filter_wpseo_canonical', 10, 1 );

/**
 * Disable Yoast SEO Schema JSON-LD
 */

function bybe_remove_yoast_json($data){
    $data = array();
    return $data;
}
add_filter('wpseo_json_ld_output', 'bybe_remove_yoast_json', 10, 1);

/**
 * Disable JSON API
 */
function disable_json_api () {

  // Filters for WP-API version 1.x
  add_filter('json_enabled', '__return_false');
  add_filter('json_jsonp_enabled', '__return_false');

  // Filters for WP-API version 2.x
  add_filter('rest_enabled', '__return_false');
  add_filter('rest_jsonp_enabled', '__return_false');

}
add_action( 'after_setup_theme', 'disable_json_api' );

function add_favicon() {
	$favicon_32 = get_stylesheet_directory_uri() . '/images/favicons/cropped-stm-logo-white-520-1-32x32.png';
	$favicon_192 = get_stylesheet_directory_uri() . '/images/favicons/cropped-stm-logo-white-520-1-192x192.png';
	$favicon_180 = get_stylesheet_directory_uri() . '/images/favicons/cropped-stm-logo-white-520-1-180x180.png';
	$favicon_270 = get_stylesheet_directory_uri() . '/images/favicons/cropped-stm-logo-white-520-1-270x270.png';
	echo '<link rel="icon" href="' . $favicon_32 . '" sizes="32x32"><link rel="icon" href="' . $favicon_192 . '" sizes="192x192"><link rel="apple-touch-icon-precomposed" href="' . $favicon_180 . '"><meta name="msapplication-TileImage" content="' . $favicon_270 . '">';
}

// First, create a function that includes the path to your favicon
function add_admin_favicon() {
  	$favicon_url = get_stylesheet_directory_uri() . '/images/favicons/favicon.ico';
	echo '<link rel="shortcut icon" href="' . $favicon_url . '">';
}
  
// Now, just make sure that function runs when you're on the login page and admin pages  
add_action('wp_head', 'add_favicon');
add_action('admin_head', 'add_admin_favicon');

/**
 * Add search box to menu
 */
// function add_search_box( $items, $args ) {
// 	if( $args->theme_location == 'shiftnav' ) {
// 	    $items .= '<li class="menu-item menu-item-search">' . get_search_form( false ) . '</li>';
// 	    return $items;
// 	}
// 	return $items;
// }
// add_filter( 'wp_nav_menu_items','add_search_box', 10, 3 );

/**
 * Check if page/post has sidebar and return css class slug
 */
function stm_has_sidebar_class($post) {
	$sidebar_layout = get_post_meta( $post->ID, 'stm_sidebar_layout', true );
	$has_sidebar = ($sidebar_layout == "right_sidebar" || $sidebar_layout == "left_sidebar");
	return ($has_sidebar) ? ' has-sidebar clearfix' : '';
}

/**
 * Remove junk from head
 */
remove_action( 'wp_head', 'rsd_link' );
remove_action( 'wp_head', 'wp_generator' );
remove_action( 'wp_head', 'feed_links', 2 );
remove_action( 'wp_head', 'index_rel_link' );
remove_action( 'wp_head', 'wlwmanifest_link' );
remove_action( 'wp_head', 'feed_links_extra', 3 );
remove_action( 'wp_head', 'start_post_rel_link', 10, 0 );
remove_action( 'wp_head', 'parent_post_rel_link', 10, 0 );
remove_action( 'wp_head', 'adjacent_posts_rel_link', 10, 0 );
remove_action( 'wp_head', 'wp_shortlink_wp_head', 10, 0 );
remove_action( 'wp_head', 'adjacent_posts_rel_link_wp_head', 10, 0 );

// Remove the REST API lines from the HTML Header
remove_action( 'wp_head', 'rest_output_link_wp_head', 10 );
remove_action( 'wp_head', 'wp_oembed_add_discovery_links', 10 );

// Remove the REST API endpoint.
remove_action( 'rest_api_init', 'wp_oembed_register_route' );

// Remove wp canonical link
//remove_action( 'wp_head', 'rel_canonical' );

// Turn off oEmbed auto discovery.
//add_filter( 'embed_oembed_discover', '__return_false' );

// Don't filter oEmbed results.
//remove_filter( 'oembed_dataparse', 'wp_filter_oembed_result', 10 );

// Remove oEmbed discovery links.
//remove_action( 'wp_head', 'wp_oembed_add_discovery_links' );

// Remove oEmbed-specific JavaScript from the front-end and back-end.
//remove_action( 'wp_head', 'wp_oembed_add_host_js' );

// Remove all embeds rewrite rules.
// add_filter( 'rewrite_rules_array', 'disable_embeds_rewrites' );

function register_main_menu() {
	register_nav_menu('desktop-menu',__( 'Desktop Menu' ));
  }
  add_action( 'init', 'register_main_menu' );
  
  
/* Sierotki na polach Wysywig ACF */
function acf_orphans($value, $post_id, $field) {
  if ( class_exists( 'iworks_orphan' ) ) {
    $orphan = new \iworks_orphan();
    $value = $orphan->replace( $value );
  }
  return $value;
}
add_filter('acf/format_value/type=text', 'acf_orphans', 10, 3);
add_filter('acf/format_value/type=textarea', 'acf_orphans', 10, 3);
add_filter('acf/format_value/type=wysiwyg', 'acf_orphans', 10, 3);


// Disable support for comments and trackbacks in post types
function df_disable_comments_post_types_support() {
	$post_types = get_post_types();
	foreach ($post_types as $post_type) {
		if(post_type_supports($post_type, 'comments')) {
			remove_post_type_support($post_type, 'comments');
			remove_post_type_support($post_type, 'trackbacks');
		}
	}
}
add_action('admin_init', 'df_disable_comments_post_types_support');

// Close comments on the front-end
function df_disable_comments_status() {
	return false;
}
add_filter('comments_open', 'df_disable_comments_status', 20, 2);
add_filter('pings_open', 'df_disable_comments_status', 20, 2);

// Hide existing comments
function df_disable_comments_hide_existing_comments($comments) {
	$comments = array();
	return $comments;
}
add_filter('comments_array', 'df_disable_comments_hide_existing_comments', 10, 2);

// Remove comments page in menu
function df_disable_comments_admin_menu() {
	remove_menu_page('edit-comments.php');
}
add_action('admin_menu', 'df_disable_comments_admin_menu');

// Redirect any user trying to access comments page
function df_disable_comments_admin_menu_redirect() {
	global $pagenow;
	if ($pagenow === 'edit-comments.php') {
		wp_redirect(admin_url()); exit;
	}
}
add_action('admin_init', 'df_disable_comments_admin_menu_redirect');

// Remove comments metabox from dashboard
function df_disable_comments_dashboard() {
	remove_meta_box('dashboard_recent_comments', 'dashboard', 'normal');
}
add_action('admin_init', 'df_disable_comments_dashboard');

// Remove comments links from admin bar
function df_disable_comments_admin_bar() {
	if (is_admin_bar_showing()) {
		remove_action('admin_bar_menu', 'wp_admin_bar_comments_menu', 60);
	}
}
add_action('init', 'df_disable_comments_admin_bar');