/**
 * STM SCRIPTS
 */

/**
 * Plugins
 */

/**
 * File skip-link-focus-fix.js.
 *
 * Helps with accessibility for keyboard only users.
 *
 * Learn more: https://git.io/vWdr2
 */
( function() {
	var isWebkit = navigator.userAgent.toLowerCase().indexOf( 'webkit' ) > -1,
	    isOpera  = navigator.userAgent.toLowerCase().indexOf( 'opera' )  > -1,
	    isIe     = navigator.userAgent.toLowerCase().indexOf( 'msie' )   > -1;

	if ( ( isWebkit || isOpera || isIe ) && document.getElementById && window.addEventListener ) {
		window.addEventListener( 'hashchange', function() {
			var id = location.hash.substring( 1 ),
				element;

			if ( ! ( /^[A-z0-9_-]+$/.test( id ) ) ) {
				return;
			}

			element = document.getElementById( id );

			if ( element ) {
				if ( ! ( /^(?:a|select|input|button|textarea)$/i.test( element.tagName ) ) ) {
					element.tabIndex = -1;
				}

				element.focus();
			}
		}, false );
	}
})();

/**
 * Scripts Scope
 */

(function() {

	var stm = {
		ignoreEvents: false
	};

	// left: 37, up: 38, right: 39, down: 40,
	// spacebar: 32, pageup: 33, pagedown: 34, end: 35, home: 36
	var keys = {37: 1, 38: 1, 39: 1, 40: 1};

	function preventDefault(e) {
	  e = e || window.event;
	  if (e.preventDefault) {
	      e.preventDefault();
	  }
	  e.returnValue = false;  
	}

	function preventDefaultForScrollKeys(e) {
	    if (keys[e.keyCode]) {
	        preventDefault(e);
	        return false;
	    }
	}

	function disableScroll() {
	  if (window.addEventListener) {// older FF
	      window.addEventListener('DOMMouseScroll', preventDefault, false);
	  }
	  window.onwheel = preventDefault; // modern standard
	  window.onmousewheel = document.onmousewheel = preventDefault; // older browsers, IE
	  window.ontouchmove  = preventDefault; // mobile
	  document.onkeydown  = preventDefaultForScrollKeys;
	}

	function enableScroll() {
	    if (window.removeEventListener) {
	        window.removeEventListener('DOMMouseScroll', preventDefault, false);
	    }
	    window.onmousewheel = document.onmousewheel = null; 
	    window.onwheel = null; 
	    window.ontouchmove = null;  
	    document.onkeydown = null;  
	}

	function stmGallery(galleryType) {

		var constGalleryType = galleryType || 'images';

		var removeGallery = function(gId) {
			setTimeout(function() {
				if(constGalleryType === 'images') {
					jQuery('#' + gId + '-display').slick('unslick');
				}
				jQuery('#' + gId + '-display').remove();
				jQuery('#' + gId + '-overlay').remove();
				jQuery('#' + gId + '-close').off().remove();
				jQuery('body').removeClass('scrolled gallery-on gallery-removing');
				enableScroll();
				stm.ignoreEvents = false;
			}, 210);
			window.removeEventListener('hashchange', hashChangeHandler, false);
		};
		var closeGallery = function(id) {
			if(stm.ignoreEvents) {
				return;
			}
			stm.ignoreEvents = true;
			var galleryId = (typeof id === 'string') ? id : jQuery(this).attr('id').replace(/-close/g,'');
			// console.log('close gallery', galleryId);
			jQuery('body').addClass('gallery-removing');
			history.replaceState('', document.title, window.location.pathname + window.location.search);
			removeGallery(galleryId);
		};

		var getGalleryTmpl = function(galleryElement) {
			var galleryString = '';
			if(constGalleryType === 'images') {
				var items = jQuery(galleryElement).find('.gallery-icon');
				items.each(function(index, item) {
					galleryString += '<div class="' + jQuery(item).attr('class') + '">';
					galleryString += '<img data-lazy="' + jQuery(item).find('a').attr('href') + '">';
					//galleryString += '<svg width="40" height="40" viewbox="0 0 40 40" class="stm-gallery-loader">';
					galleryString += '<polygon points="0 0 0 40 40 40 40 0" class="loader-inner" /></svg></div>';
				});
			} else if(constGalleryType === 'videos') {
				galleryString += '<iframe class="stm-yt-iframe" width="100%" height="100%" src="' + galleryElement.attr('href').replace(/watch\?v=/g, 'embed/') + '?rel=0"></iframe>';
			} else if(constGalleryType === 'folder') { 
				
				var delimiter = '/',
					elHref = galleryElement.attr('href'),
					cdn = true,
				    start = 3,
				    tokens = elHref.split(delimiter).slice(start),
				    result = tokens.join(delimiter);
			    if(cdn) {
			    	result = window.location.origin + '/' + result;
			    } else {
			    	result = elHref;
			    }
				//console.log(result);
				galleryString += '<iframe class="pdfjs-viewer" width="100%" height="100%" src="/wp-content/plugins/pdf-viewer/stable/web/viewer.html?file=' + result + '"></iframe>';
			}
			return galleryString;
		};

		var bindSlick = function(galleryId, itemId) {
			jQuery('#' + galleryId + '-display').slick({
				autoplay: true,
				autoplaySpeed: 5000,
				pauseOnHover: true,
				lazyLoad: 'ondemand',
				slidesToShow: 1,
				slidesToScroll: 1,
				prevArrow: stm.arrows.prevArrow,
				nextArrow: stm.arrows.nextArrow,
				initialSlide: itemId
			});
		};

		var makeGallery = function(galleryElement, itemId) {
			var galleryString = getGalleryTmpl(galleryElement);
			var galleryId = jQuery(galleryElement).attr('id') || 'gallery-' + itemId;

			history.pushState('', document.title, window.location.pathname + '#' + galleryId);

			var mainWrapper = '<div id="' + galleryId + '-display" class="stm-gallery-display">' + galleryString + '</div>';
			mainWrapper += '<div id="' + galleryId + '-overlay" class="stm-gallery-overlay"></div>';
			mainWrapper += '<div id="gallery-bar">';
			mainWrapper += '<span id="' + galleryId + '-close" class="stm-gallery-close">';

			mainWrapper += '</span>';
			mainWrapper += '</div>';
			jQuery('body').addClass('scrolled gallery-on').append(mainWrapper);
			
			if(constGalleryType === 'images') {
				bindSlick(galleryId, itemId);
			}

			disableScroll();
			jQuery('#' + galleryId + '-close').on('click', closeGallery);
			stm.ignoreEvents = false;
			window.addEventListener('hashchange', hashChangeHandler, false);
		};

		var init = {
			images: function() {
				//console.log('Init IMAGES Gallery');
				stm.galeries.each(function(index, gallery) {
					var gItem = jQuery(gallery).find('.gallery-item');
					gItem.find('a').on('click', function(e) {
						e.preventDefault();
						if(stm.ignoreEvents) { return; }
						stm.ignoreEvents = true;
						//console.log('make gallery');
						makeGallery(gallery, gItem.index(jQuery(this).closest('.gallery-item')));
					});
				});
			},
			videos: function() {
				//console.log('Init VIDEOS Gallery');
				jQuery('.stm-video-item').on('click', function(e) {
					e.preventDefault();
					if(stm.ignoreEvents) { return; }
					stm.ignoreEvents = true;
					makeGallery(jQuery(this), Math.floor(Math.random() * 100));
				});
			},
			folder: function() {
				//console.log('Init FOLDER Gallery');
				stm.folder.on('click', function(e) {
					e.preventDefault();
					if(stm.ignoreEvents) { return; }
					stm.ignoreEvents = true;
					makeGallery(jQuery(this), Math.floor(Math.random() * 100));
				});
			}
		};

		function hashChangeHandler(ev) {
			var splitHash = ev.oldURL.split('#');
			var newHash = splitHash[splitHash.length - 1];
			if(!/^http/.test(newHash)) {
				closeGallery(newHash);
			}
		}

		init[galleryType]();
	}

	function stmVideosGallery() {
		if(stm.videosPage.length) {
			stmGallery('videos');
		}
	}

	function stmImagesGallery() {
		if(stm.galeries.length) {
			stmGallery('images');
		}
	}

	function stmFolderGallery() {
		if(stm.folder.length) {
			stmGallery('folder');
		}
	}

	function featuredHover() {
		if(stm.featuredElements.length) {
			stm.featuredElements.find('div + p + p').hover(
				function() { jQuery(this).parent('li').addClass('hovered'); },
				function() { jQuery(this).parent('li').removeClass('hovered'); }
			);
			stm.featuredElements.find('a').on('click', function() {
				var lbl = jQuery(this).parents('li').find('div i').text();
				lbl = 'banner_' + lbl.replace(/ /g, '_');
				ga('send', 'event', {
					eventCategory: 'web.homepage',
					eventAction: 'click',
					eventLabel: lbl.toLowerCase(),
				    transport: 'beacon'
				});
			});
		}
	}

	function showMainSlider() {
		if(stm.mainSlider.length) {
			stm.mainSlider.find('.s-article').addClass(function(index) {
			  return 'stm-slider-' + (index + 1);
			});
			stm.mainSlider.addClass('on');
		}
	}

	function initStmSliders() {
		if(stm.sliders.length) {
			stm.sliders.slick({
				prevArrow: stm.arrows.prevArrow,
				nextArrow: stm.arrows.nextArrow,
				 autoplay: true,
				autoplaySpeed: 5000,
					pauseOnHover: false 
			});
		}
	}

	function scrollHandler() {
		if(jQuery(window).scrollTop() > 100) {
			stm.rootElement.addClass('scrolled');
		} else {
			stm.rootElement.removeClass('scrolled');
		}
	}

	function resizeHandler($ev) {
		//console.log('resize ', $ev);
	}

	function setWindowListeners() {
		jQuery(document).on('scroll', _.throttle(scrollHandler, 100));
		//jQuery(window).on('resize', _.throttle(resizeHandler, 200));
	}

	var cookieConsentContent = {
		'en-GB': {
			message: 'This website uses cookies to ensure you get the best experience.',
			dismiss: 'Got it',
			link: 'Learn more',
			href: '/cookie-policy/'
		},
		'es-ES': {
			message: 'Este sitio web utiliza cookies para asegurar que obtenga la mejor experiencia.',
			dismiss: 'Entiendo',
			link: 'Aprende más',
			href: '/es/politica-de-cookies/'
		},
		'fr-FR': {
			message: 'Ce site Web utilise des cookies pour vous assurer d\'obtenir la meilleure expérience sur notre site Web.',
			dismiss: 'Je l\'ai',
			link: 'Lire la suite',
			href: '/fr/cookies/'
		},
		'pl-PL': {
			message: 'Ta strona wykorzystuje pliki cookies.',
			dismiss: 'Rozumiem',
			link: 'Dowiedz się więcej',
			href: '/pl/pliki-cookie/'
		}
	};

	function cookieConsent() {
		if(!cookieConsentContent[stm.lang]) {
			return;
		}
		var getGaBeacon = function(isLoad) {
			return {
				eventCategory: 'web',
				eventAction: (isLoad) ? 'load' : 'click',
				eventLabel: ((isLoad) ? 'cookie_consent_' : 'dismiss_cookie_') + stm.lang,
				transport: 'beacon'
			};
		};
		window.cookieconsent.initialise({
		  palette: {
		    popup: {
		      background: '#666666'
		    },
		    button: {
		      background: '#224585'
		    }
		  },
		  theme: 'classic',
		  content: cookieConsentContent[stm.lang],
		  onPopupOpen: function() {
		  	if(!this.hasConsented()) {
		  		//console.log('SEND COOKIE LOAD', getGaBeacon(true));
		  		ga('send', 'event', getGaBeacon(true));
		  	}
		  },
		  onPopupClose: function() {
		  	//console.log('COOKIE CLOSE', getGaBeacon());
		  	ga('send', 'event', getGaBeacon());
		  }
		});
	}

	var domain = ['stm-','pack.','com'].join('');
	function emailHTML(addr, withLabel) {
		var prefix = (withLabel) ? 'email: ' : '';
		var address = addr + '@' + domain;
		return prefix + '<a href="ma' + 'ilt' + 'o:' + address + '">' + address + '</a>';
	}

	function telHTML(addr, withLabel) {
		var prefix = (withLabel) ? 'tel: ' : '';
		return prefix + '<a href="tel:' + addr.replace(/ /g, '') + '">' + addr + '</a>';
	}

	function emailReplacement() {
		if(!stm.emails[1].length) {
			return;
		}
		var emails = stm.emails[1];
		var attr = stm.emails[0];
		var replace = function() {
			emails.each(function(ind, el) {
				var jqEl = jQuery(el);
				var elAttr = jqEl.attr(attr);
				jqEl.append(emailHTML(elAttr, true));
			});
		};
		setTimeout(replace, 500);
	}

	function globalContactWidget() {

		var widgetId = '#contact_widget';
		var contact = {
			tel: {
				office: '+4894 367 14 71',
				cis: '+48504 905 120',
				service: '+48604 189 802'
			},
			email: {
				office: 'contact',
				cis: ['af','russia'],
				service: 'service'
			}
		};

		var getContact = {
			email: function(slug) {
				if(typeof contact.email[slug] !== 'string') {
					var str = '';
					contact.email[slug].forEach(function(s) {
						str += emailHTML(s);
					});
					return str;
				}
				return emailHTML(contact.email[slug]);
			},
			tel: function(slug) {
				return telHTML(contact.tel[slug]);
			}
		};

		console.log(getContact.tel('office'));
		console.log(getContact.email('office'));

		var widget = {
			id: widgetId,
			idButton: widgetId + '_button',
			idTitle: widgetId + '_header',
			idClose: widgetId + '_close',
			opened: false,
			isOnScreen: false,
			icons: {
				phone: '<svg class="contact-widget-icon phone-icon" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 500 500" preserveAspectRatio="xMinYMin meet"><path style="stroke:none; fill:#fff;" d="M249.661,4.024C114.295,4.024,4.559,113.761,4.559,249.127c0,135.365,109.736,245.102,245.103,245.102 s245.103-109.736,245.103-245.102C494.764,113.761,385.027,4.024,249.661,4.024z M249.661,43.166 c113.735,0,205.961,92.226,205.961,205.961c0,113.735-92.226,205.926-205.961,205.926c-113.736,0-205.926-92.19-205.926-205.926 C43.735,135.391,135.925,43.166,249.661,43.166z M143.778,105.242L115.5,133.521c-0.259,0.236-0.499,0.499-0.748,0.748 c-25.806,25.805,8.628,102.085,76.928,170.382s144.612,102.769,170.418,76.964l-0.036-0.035l29.026-29.026l-73.153-73.153 l-29.026,29.026l0.072,0.071c-6.922,6.921-35.157-10.085-63.075-38.001c-27.917-27.917-44.922-56.153-38.001-63.075l29.026-29.026 L143.778,105.242z"/></svg>',
				mail: '<svg class="contact-widget-icon mail-icon" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 438.72 438.72" preserveAspectRatio="xMinYMin meet"><path style="stroke:none; fill:#fff;" d="M 219.0625 3.53125 C 100.28694 3.53125 4 99.818214 4 218.59375 C 4 337.3693 100.28694 433.65625 219.0625 433.65625 C 337.83805 433.65625 434.125 337.3693 434.125 218.59375 C 434.125 99.818214 337.83805 3.53125 219.0625 3.53125 z M 219.0625 37.875 C 318.85874 37.875 399.78125 118.79751 399.78125 218.59375 C 399.78125 318.38999 318.85874 399.28125 219.0625 399.28125 C 119.26626 399.28125 38.375 318.38999 38.375 218.59375 C 38.375 118.79751 119.26626 37.875 219.0625 37.875 z M 104 124.5625 L 219.59375 206.96875 L 335.1875 124.5625 L 219.59375 124.5625 L 104 124.5625 z M 82.09375 140.1875 L 82.09375 293.65625 L 167.34375 201 L 82.09375 140.1875 z M 357.125 140.1875 L 271.875 201 L 357.125 293.65625 L 357.125 140.1875 z M 188.4375 216 L 99.5625 312.625 L 219.59375 312.625 L 339.65625 312.625 L 250.78125 216 L 219.59375 238.25 L 188.4375 216 z"/></svg>'
			},
			content: {
				'en-GB': {
					title: 'Contact',
					copy: {
						opened: 'Our office is now open. You can call us on ' + getContact.tel('office'),
						closed: 'We are closed'
					},
					link: ''
				},
				'es-ES': {
					title: 'Contact es-ES',
					copy: {
						opened: 'We are open',
						closed: 'We are closed'
					}
				},
				'fr-FR': {
					title: 'Contact',
					copy: {
						opened: 'We are open',
						closed: 'We are closed'
					}
				},
				'pl-PL': {
					title: 'Contact',
					copy: {
						opened: 'We are open',
						closed: 'We are closed'
					}
				},
				'fa-FA': {
					title: 'Contact',
					copy: {
						opened: 'We are open',
						closed: 'We are closed'
					}
				}
			},
			activate: function() {
				jQuery(widget.idButton).addClass('activated');
				jQuery(widget.idClose).append(jQuery('.stm-cross').clone(true)).on('click', widget.offScreen);
			},
			getOpeningHours: function(clbk) {
				jQuery.get(stm.awsapi.envurl + stm.awsapi.api.place)

				.fail(function(err) {
					console.log('API Get Place error:', err);
				})

				.always(function(resp, status) {
					if(clbk) {
						if(status === 'success') {
							resp = resp.result.opening_hours;
						}
						resp.status = status;
						clbk(resp); 
					}
				});
			},
			getWidgetTmpl: function() {
				var tmpl = '<span id="' + this.idButton.substr(1) + '" class="contact-widget-button">';
				tmpl += this.icons.phone;
				tmpl += this.icons.mail;
				tmpl += '</span>';
				return tmpl;
			},
			setState: function(isOpen) {
				this.opened = isOpen;
				jQuery(widget.idButton).toggleClass('opened', isOpen).toggleClass('closed', !isOpen);
			},
			onScreen: function() {
				console.log('Contact widget on screen');
				var lclContent = widget.content[stm.lang];
				var lclCopy = (widget.opened) ? lclContent.copy.opened : lclContent.copy.closed;
				var title = '<h1 class="widget-title">' + lclContent.title + '</h1>';
				title += '<p class="widget-copy">' + lclCopy + '</p>';
				jQuery(widget.idTitle).html(title);
				jQuery(widget.id).removeClass('hidden');
				setTimeout(function() {
					jQuery(widget.id).addClass('on-screen');
				}, 200);
			},
			offScreen: function() {
				console.log('Contact widget off screen');
				jQuery(widget.id).addClass('hidden').removeClass('on-screen');
			},
			isPublic: false,
			hasDevQuery: false,
			devQueryOpened: false
		};

		var resolveState = function(d) {
			if(!widget.isPublic && widget.hasDevQuery) {
				return widget.devQueryOpened;
			}
			return (d.status === 'success' && d.open_now);
		};

		var widgetButtonClickHandler = function() {
			if(widget.isOnScreen) {
				return;
			}
			widget.onScreen();

		};

		if(!widget.isPublic) {
			var sq = window.location.search.substr(2);
			if(sq.length && (sq === 'opened' || sq === 'closed')) {
				widget.hasDevQuery = true;
				widget.devQueryOpened = (sq === 'opened');
			}
		}

		if(widget.isPublic || widget.hasDevQuery) {
			var init = function(d) {
				widget.setState(resolveState());
				jQuery(widget.idButton).on('click', widgetButtonClickHandler);
				setTimeout(widget.activate, 800);
			};
			jQuery('body').append(widget.getWidgetTmpl());
			widget.getOpeningHours(init);
		}
	}

	function addPrivacyPolicyLink() {
		if(!stm.hasContactForm.length || stm.lang === 'ru-RU' || stm.lang === 'fa-IR') {
			return;
		}
		var locales = {
			'en': {
				link: '/privacy-policy',
				cta: 'Our Privacy Policy'
			},
			'pl': {
				link: '/pl/polityka-prywatnosci',
				cta: 'Polityka prywatności'
			},
			'es': {
				link: '/es/politica-de-privacidad/',
				cta: 'Política de privacidad'
			},
			'fr': {
				link: '/fr/politique-de-confidentialite/',
				cta: 'Politique de confidentialité'
			}
		};
		var langIso = stm.lang.split('-')[0];
		var link = locales[langIso].link;
		var popupContainer = document.createElement('div');
		
		var popupRemoval = document.createElement('span');
		
		jQuery(popupRemoval).addClass('privacy-policy-close').attr('id', 'privacy_policy_close').html('<svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 1000 1000"><g><path d="M133.3,993.1c-30.8,0-61.6-12.3-86.3-37c-49.3-49.3-49.3-129.4,0-178.7L774.3,50.1c49.3-49.3,129.4-49.3,178.7,0c49.3,49.3,49.3,129.4,0,178.7L219.6,956.1C194.9,980.8,164.1,993.1,133.3,993.1z"/><path d="M860.6,986.9c-30.8,0-61.6-12.3-86.3-37L47,222.6C-2.3,173.3-2.3,93.2,47,43.9c49.3-49.3,129.4-49.3,178.7,0L953,771.2c49.3,49.3,49.3,129.4,0,178.7C928.4,974.6,897.5,986.9,860.6,986.9z"/></g></svg>');
		function popupClose() {
			jQuery(popupContainer).addClass('hidden');
		}
		function popupOpen(event) {
			event.preventDefault();
			jQuery(popupContainer).removeClass('hidden');
		}
		function popupReady() {
			jQuery(popupContainer).addClass('hidden privacy-popup');
			jQuery(popupContainer).find('.site-main').attr('id', 'privacy_popup');
			jQuery('body').append(popupContainer);
			
			jQuery('#privacy_popup').children().first().addClass('privacy-container').append(popupRemoval);
			
			jQuery('[data-directive="privacy-policy-link"]').on('click', popupOpen);

			jQuery(popupRemoval).on('click', popupClose);
		}
		jQuery(popupContainer).load( link + ' #main', popupReady);
	}

	stm.functions = [
		cookieConsent,
		showMainSlider,
		initStmSliders,
		setWindowListeners,
		scrollHandler,
		featuredHover,
		stmVideosGallery,
		stmImagesGallery,
		stmFolderGallery,
		emailReplacement,
		addPrivacyPolicyLink
	];

	function initStmScripts() {

		stm.env = {
			label: 'prod',
			prod: true,
			dev: false
		}
		if(window.location.hostname === 'localhost') {
			stm.env.label = 'dev';
			stm.env.prod = !stm.env.prod;
			stm.env.dev = !stm.env.dev;
		}

		stm.sliders = jQuery('.stm-slider');
		stm.mainSlider = jQuery('#slider');
		stm.rootElement = jQuery('html');
		stm.productIcons = jQuery('.product-icons');
		stm.featuredElements = jQuery('.featured-blocks');
		stm.videosPage = jQuery('.stm-video-item');
		stm.galeries = jQuery('.gallery');
		stm.folder = jQuery('.stm-folder');
		stm.arrows = {
			left: '<svg version="1.1" viewBox="0 0 32 32" xmlns="http://www.w3.org/2000/svg"><path d="M7.701,14.276l9.586-9.585c0.879-0.878,2.317-0.878,3.195,0l0.801,0.8c0.878,0.877,0.878,2.316,0,3.194  L13.968,16l7.315,7.315c0.878,0.878,0.878,2.317,0,3.194l-0.801,0.8c-0.878,0.879-2.316,0.879-3.195,0l-9.586-9.587  C7.229,17.252,7.02,16.62,7.054,16C7.02,15.38,7.229,14.748,7.701,14.276z"/></svg>',
			right: '<svg version="1.1" viewBox="0 0 32 32" xmlns="http://www.w3.org/2000/svg"><path d="M24.291,14.276L14.705,4.69c-0.878-0.878-2.317-0.878-3.195,0l-0.8,0.8c-0.878,0.877-0.878,2.316,0,3.194  L18.024,16l-7.315,7.315c-0.878,0.878-0.878,2.317,0,3.194l0.8,0.8c0.878,0.879,2.317,0.879,3.195,0l9.586-9.587  c0.472-0.471,0.682-1.103,0.647-1.723C24.973,15.38,24.763,14.748,24.291,14.276z"/></svg>'
		};
		stm.arrows.prevArrow = '<span class="stm-arrow left-arrow">' + stm.arrows.left + '</span>';
		stm.arrows.nextArrow = '<span class="stm-arrow right-arrow">' + stm.arrows.right + '</span>';

		stm.emails = ['data-ereplace'];
		stm.emails.push(jQuery('[' + stm.emails[0] + ']'));

		stm.time = {
			server: (typeof stmPageCT === 'number') ? stmPageCT : null,
			client: + new Date()
		};

		stm.lang = jQuery('html').attr('lang');

		stm.awsapi = {
			url: 'https://4g5ou1bnr5.execute-api.us-east-1.amazonaws.com/',
			dev: 'dev/',
			prod: 'prod/',
			api: {
				place: 'get-google-place/'
			}
		};

		stm.hasContactForm = jQuery('.wpcf7-form');

		stm.awsapi.envurl = stm.awsapi.url + ((stm.env.dev) ? stm.awsapi.dev : stm.awsapi.prod);

		// console.log('aws api url: ', stm.awsapi.envurl);

		for(var i = 0; i < stm.functions.length; i++) {
			stm.functions[i]();
		}
	}

	jQuery(document).ready(initStmScripts);
})();

